==> haskell-cabal-helper-0.6.3.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cabal-helper/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-helper
version: 0.6.3.1
id: cabal-helper-0.6.3.1-f693884c4459a26ffacfdfb6007951f0
key: cabal_EdIGXVnk4NM7Yx3mAW3pdO
license: AGPL-3
maintainer: dxld@darkboxed.org
synopsis: Simple interface to some of Cabal'\''s configuration state used by ghc-mod
description:
    @cabal-helper@ provides a library which wraps the internal use of
    anexecutable to lift the restrictions imposed by linking against versions of
    GHC before @7.10@. This has the pleasant side effect of isolating the user
    from having to deal with Cabal version changes manually as @cabal-helper@
    can simply recompile it'\''s helper program automatically as needed.
    .
    @cabal-helper@ uses a wrapper executable to compile the actual cabal-helper
    executable at runtime while linking against an arbitrary version of
    Cabal. This runtime-compiled helper executable is then used to extract
    various bits and peices from Cabal\'\''s on disk state (dist/setup-config)
    written by it'\''s configure command.
    .
    In addition to this the wrapper executable also supports installing any
    version of Cabal from hackage in case it cannot be found in any available
    package database. The wrapper installs these instances of the Cabal library
    into a private package database so as to not interfere with the user'\''s
    packages.
    .
    Furthermore the wrapper supports one special case namely reading a state
    file for Cabal itself. This is needed as Cabal compiles it'\''s Setup.hs using
    itself and not using any version of Cabal installed in any package database.
    .
    @cabal-helper@ can compile with @Cabal >= 1.14@ but requires @Cabal >= 1.16@
    at runtime.
category: Distribution
author: Daniel Gröber <dxld@darkboxed.org>
exposed: True
exposed-modules:
    Distribution.Helper
hidden-modules: Paths_cabal_helper CabalHelper.Types
                CabalHelper.Sandbox
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cabal-helper-0.6.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/cabal-helper-0.6.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/cabal-helper-0.6.3.1
hs-libraries: HScabal-helper-0.6.3.1-EdIGXVnk4NM7Yx3mAW3pdO
depends:
    Cabal-1.22.5.0-9b2e7feff1fc55070a0a783f283ee9b6
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/cabal-helper/html/cabal-helper.haddock
haddock-html: /usr/share/doc/cabal-helper/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-helper-0.6.3.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cabal-helper/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cabal-helper
version: 0.6.3.1
id: cabal-helper-0.6.3.1-512cee1d780890ae55b68b9cff633e01
key: cabal_3g6YHQHZFzd4tYIv6IHNqX
license: AGPL-3
maintainer: dxld@darkboxed.org
synopsis: Simple interface to some of Cabal'\''s configuration state used by ghc-mod
description:
    @cabal-helper@ provides a library which wraps the internal use of
    anexecutable to lift the restrictions imposed by linking against versions of
    GHC before @7.10@. This has the pleasant side effect of isolating the user
    from having to deal with Cabal version changes manually as @cabal-helper@
    can simply recompile it'\''s helper program automatically as needed.
    .
    @cabal-helper@ uses a wrapper executable to compile the actual cabal-helper
    executable at runtime while linking against an arbitrary version of
    Cabal. This runtime-compiled helper executable is then used to extract
    various bits and peices from Cabal\'\''s on disk state (dist/setup-config)
    written by it'\''s configure command.
    .
    In addition to this the wrapper executable also supports installing any
    version of Cabal from hackage in case it cannot be found in any available
    package database. The wrapper installs these instances of the Cabal library
    into a private package database so as to not interfere with the user'\''s
    packages.
    .
    Furthermore the wrapper supports one special case namely reading a state
    file for Cabal itself. This is needed as Cabal compiles it'\''s Setup.hs using
    itself and not using any version of Cabal installed in any package database.
    .
    @cabal-helper@ can compile with @Cabal >= 1.14@ but requires @Cabal >= 1.16@
    at runtime.
category: Distribution
author: Daniel Gröber <dxld@darkboxed.org>
exposed: True
exposed-modules:
    Distribution.Helper
hidden-modules: Paths_cabal_helper CabalHelper.Types
                CabalHelper.Sandbox
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cabal-helper-0.6.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/cabal-helper-0.6.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/cabal-helper-0.6.3.1
hs-libraries: HScabal-helper-0.6.3.1-3g6YHQHZFzd4tYIv6IHNqX
depends:
    Cabal-1.22.5.0-9b2e7feff1fc55070a0a783f283ee9b6
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/cabal-helper/html/cabal-helper.haddock
haddock-html: /usr/share/doc/cabal-helper/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
